// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIMAP_VERSION_H
#define KIMAP_VERSION_H

#define KIMAP_VERSION_STRING "6.7.1"
#define KIMAP_VERSION_MAJOR 6
#define KIMAP_VERSION_MINOR 7
#define KIMAP_VERSION_PATCH 1
#define KIMAP_VERSION ((6<<16)|(7<<8)|(1))

#endif
